@@ -5,10 +5,11 @@
 #' @details A `crew` relay object keeps the signaling relationships
 #'   among condition variables.
 #' @return An `R6` `crew` relay object.
+#' @param throttle A [crew_throttle()] object.
 #' @examples
 #' crew_relay()
-crew_relay <- function() {
-  relay <- crew_class_relay$new()
+crew_relay <- function(throttle = crew_throttle()) {
+  relay <- crew_class_relay$new(throttle = throttle)
   relay$validate()
   relay
 }
@@ -26,7 +27,8 @@ crew_class_relay <- R6::R6Class(
   private = list(
     .condition = NULL,
     .from = NULL,
-    .to = NULL
+    .to = NULL,
+    .throttle = NULL
   ),
   active = list(
     #' @field condition Main condition variable.
@@ -40,9 +42,19 @@ crew_class_relay <- R6::R6Class(
     #' @field to Condition variable to relay to.
     to = function() {
       .subset2(private, ".to")
+    },
+    #' @field throttle A [crew_throttle()] object for `wait()`.
+    throttle = function() {
+      .subset2(private, ".throttle")
     }
   ),
   public = list(
+    #' @description Relay constructor.
+    #' @return A [crew_relay()] object.
+    #' @param throttle A [crew_throttle()] object.
+    initialize = function(throttle) {
+      private$.throttle <- throttle
+    },
     #' @description Validate the object.
     #' @return `NULL` (invisibly).
     validate = function() {
@@ -51,6 +63,7 @@ crew_class_relay <- R6::R6Class(
           crew_assert(inherits(private[[field]], "conditionVariable"))
         }
       }
+      private$.throttle$validate()
       invisible()
     },
     #' @description Start the relay object.
@@ -90,10 +103,9 @@ crew_class_relay <- R6::R6Class(
     #' @description Wait until an unobserved task resolves or the timeout
     #'   is reached. Use the throttle to determine the waiting time.
     #' @return `NULL` (invisibly).
-    #' @param throttle A [crew_throttle()] object to orchestrate the
-    #'   wait time intervals.
-    wait = function(throttle) {
+    wait = function() {
       condition <- .subset2(self, "condition")
+      throttle <- .subset2(private, ".throttle")
       timeout <- .subset2(throttle, "seconds_interval") * 1000
       signal <- nanonext::until_(cv = condition, msec = timeout)
       .subset2(throttle, "update")(signal)
