@@ -11,23 +11,12 @@ crew_test("test auto-scaling of workers", {
   }
   # Wait for the tasks to complete.
   controller$wait()
-  # Wait for the workers to idle out and exit on their own.
-  crew_retry(
-    ~all(controller$client$summary()$online == FALSE),
-    seconds_interval = 1,
-    seconds_timeout = 60
-  )
   # Do the same for 100 more tasks.
   for (index in (seq_len(100L) + 100L)) {
     name <- paste0("task_", index)
     controller$push(name = name, command = index, data = list(index = index))
   }
   controller$wait()
-  crew_retry(
-    ~all(controller$client$summary()$online == FALSE),
-    seconds_interval = 1,
-    seconds_timeout = 60
-  )
   # Collect the results.
   results <- NULL
   while (!is.null(out <- controller$pop(scale = FALSE))) {
